%==========================================================================
%
%  Characteristic Impedance of a Microstrip line.
%
%   See Pozar notes.
%
%==========================================================================
%
%   James Nagel
%   Department of Electrical and Computer Engineering
%   University of Utah, Salt Lake City, Utah
%   nageljr@ieee.org
%   Copyright February 21, 2012

function Z0 = Microstrip_Impedance(W,d,er)


%  Effective dielectric constant.
e1 = (er + 1)/2;
e2 = (er - 1)/2;
e_e = e1 + e2*1/sqrt(1 + 12*d/W);

if W/d <= 1
    Z0 = 60/sqrt(e_e)*log(8*d/W + W/(4*d));
else
    u = W/d + 1.393 + 0.667*log(W/d + 1.444);
    Z0 = 120*pi/(sqrt(e_e)*u);
end

