%==========================================================================
%
%   ECE 5340/6340 homework 5.
%
%   Solve for the capacitor plate potentials using SOR.
%
%       E-field produced by two parallel capacitor plates.  The top plate
%   is at a uniform potential of +1.0 V while the bottom plate is at a
%   uniform potential of -1.0 V.  
%
%==========================================================================
%
%   James Nagel
%   Department of Electrical and Computer Engineering
%   University of Utah, Salt Lake City, Utah
%   nageljr@ieee.org
%   Copyright February 8, 2012

close all;
clear all;

%==========================================================================
%  Simulation parameters.
%==========================================================================

W  = 1e-2;
d  = 3e-3;
er = 3;


%==========================================================================
%  Numerically solve Poisson's equation for this geometry.  This should
%  take up about 95% of the run-time for this code.
%==========================================================================
[V,h,EPS] = Solve_Microstrip(W,d,er);


%  Set up the axes.
[Ny,Nx] = size(V);
x = 0 : h : (Nx-1)*h;
y = 0 : h : (Ny-1)*h;
x = x - mean(x);

x = x*1e2;
y = y*1e2;

xMin = min(x);
xMax = max(x);
yMin = min(y);
yMax = max(y);


%==========================================================================
%   Start rendering the potential image.
%==========================================================================
fig = figure(1);
clf
imagesc(x,y,V);
axis equal
axis([xMin xMax yMin yMax ]);
axis xy;
colormap jet;
X = xlabel('Distance (cm)');
Y = ylabel('Distance (cm)');
set(X,'fontname','verdana','fontsize',24);
set(Y,'fontname','verdana','fontsize',24);
set(gca,'fontsize',18);
title('Voltage Potential (V)','fontname','verdana','fontsize',24);

%  Tweak the figure to make it look better.
set(fig,'units','normalized','position',[0.1, 0.1, 0.8, 0.8*Ny/Nx]);


%==========================================================================
%  Render another identical image for the E-fields.
%==========================================================================

[Ex,Ey,Emag] = staggered_2D_gradient(V,h);
Emag = sqrt(Ex.^2 + Ey.^2);
xe = linspace(xMin + h/2,xMax - h/2,Nx-1);
ye = linspace(yMin + h/2,yMax - h/2,Ny-1);

fig = figure(2);
clf
imagesc(xe,ye,Emag);
axis xy
axis equal
axis([xMin xMax yMin yMax ]);
colormap jet;
X = xlabel('Distance (cm)');
Y = ylabel('Distance (cm)');
set(X,'fontname','verdana','fontsize',24);
set(Y,'fontname','verdana','fontsize',24);
set(gca,'fontsize',18);
title('Electric Field (V/m)','fontname','verdana','fontsize',24);

%  Make the figures look nice and pretty.
%  Tweak the figure to make it look better.
set(fig,'units','normalized','position',[0.1, 0.5, 0.8, 0.8*Ny/Nx]);

%==========================================================================
%  Simulate an identical system but without any dielectrics.
%==========================================================================
[V0,h] = Solve_Microstrip(W,d,1);
[Ex0,Ey0] = staggered_2D_gradient(V0,h);

%==========================================================================
%  Calculate capacitance for each simulation.
%==========================================================================

%  Physical constants.
e_0 = 8.854e-12;    %  Permittivity of free-space.
c_0 = 3e8;          %  Speed of light in a vacuum.

%  Voltage of top strip.
Vtop = 1;

%  Solve for indices of the Gaussian contour vertices.
x1 = round(W/2/h);
x2 = Nx - x1;
y1 = round(d/2/h);
y2 = round(d/h) + y1;

%  Gaussian contour for dielectric simulation.
qL = trapz(EPS(y1:y2,x1).*Ex(y1:y2,x1));
qR = trapz(EPS(y1:y2,x2).*Ex(y1:y2,x2));
qT = trapz(EPS(y2,x1:x2).*Ey(y2,x1:x2));
qB = trapz(EPS(y1,x1:x2).*Ey(y1,x1:x2));

q = e_0*h*(-qL + qR + qB - qT);
C = q/Vtop;

%  Gaussian contour for free-space simulation.
qL = trapz(Ex0(y1:y2,x1));
qR = trapz(Ex0(y1:y2,x2));
qT = trapz(Ey0(y2,x1:x2));
qB = trapz(Ey0(y1,x1:x2));

q0 = e_0*h*(-qL + qR + qB - qT);
C0 = q0/Vtop;

%  Characteristic Impedance. 
Z0 = (1/c_0)*1/sqrt(C*C0);

%  Calculate analyical value.
Z0_calc = Microstrip_Impedance(W,d,er);

%  Display results.
disp(Z0);
disp(Z0_calc);



