%==========================================================================
%
%   ECE 5340/6340 homework 6.
%
%   Solve for the voltage potential of a microstrip line.  This time apply
%   a NEUMANN BOUNDARY along the center of the domain to exploit symmetry.
%
%   INPUTS:
%       W = Top strip width (m)
%       d = Dielectric spacing (m)
%      er = Dielectric constant of substrate.
%
%   OUTPUTS:
%       V = Voltage potential function (V).
%       h = Grid spacing (m).
%     EPS = Dielectric function.
%
%==========================================================================
%
%   James Nagel
%   Department of Electrical and Computer Engineering
%   University of Utah, Salt Lake City, Utah
%   nageljr@ieee.org
%   Copyright February 8, 2012

function [V,h,EPS] = Solve_Microstrip_Neumann(W,d,er)

%==========================================================================
%  Simulation parameters.
%==========================================================================

%  Specify the simulation domain size (m).
Lx = 1.5*W;
Ly = 5*d;

%  Specify grid spacing (m).  
Nd = 20;        %  Number of grid steps from bottom to stripline.
h  = d/Nd;    	%  Grid step size (m).

%  Generate axes.
x = 0 : h : Lx ;
y = 0 : h : Ly ;
%x = x - mean(x);       %  Do not center the x this time.
y = y - mean(y);

%  Number of voltage samples.
Nx = length(x);
Ny = length(y);

%  Plate parameters.
Vtop = 1;           %  Top strip potential (V).
x1   = -W/2;        %  Left tip (m).
x2   = +W/2;        %  Right tip (m).

xIDX = find(x <= x2 & x >= x1);
yIDX = Nd;

%  Solve for SOR parameters.
Ni = 1000;                              %  Total max iterations.
t  = cos(pi/Nx) + cos(pi/Ny);           %  t-parameter.
ww = ( 8 - sqrt(64 - 16*t^2) )/t^2;     %  Relaxation factor.

%==========================================================================
%  Prepare simulation parameters.
%==========================================================================

%  Initialize matrices.
V   = zeros(Ny,Nx);         %  Potential function (V).
BC  = zeros(Ny,Nx);         %  Boundary conditions (boolean).
RHO = zeros(Ny,Nx);         %  Charge distrubution (C/m^2).
EPS = ones(Ny,Nx);          %  Dielectric constants.

%  Initialize boundary conditions.  For this simulation, they are all
%  Dirichlet boundaries.
BC(1,:)   = 1;              %  Top edge
BC(end,:) = 1;              %  Bottom edge
BC(:,1)   = 0;              %  Left edge (NEUMANN BOUNDARY FLAG).
BC(:,end) = 1;              %  Right edge

%  Set the capacitor plate potentials and boundary conditions.
V( yIDX,xIDX )  = Vtop;
BC( yIDX,xIDX ) = 1;

%  Specify dielectric region.
EPS(1:yIDX,:) = er;

%==========================================================================
%  Numerically solve Poisson's equation for this geometry.  This should
%  take up about 95% of the run-time for this code.
%==========================================================================
%V = Poisson_SOR_Solver(V,BC,EPS,RHO,h,ww,Ni);
V = Poisson_FDM_Solver_2D(V,BC,EPS,RHO,h);

return;
